==> jasperreports_3.7.0+dfsg.orig.tar.gz: jasperreports-3.7.0.orig/src/net/sf/jasperreports/engine/export/oasis/JROdsExporterNature.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * Contributors:
 * Greg Hilton
 */

package net.sf.jasperreports.engine.export.oasis;

import net.sf.jasperreports.engine.export.ExporterFilter;

/**
 * @author sanda zaharia (shertage@users.sourceforge.net)
 * @version $Id: JROdsExporterNature.java 3089 2009-10-05 09:37:05Z teodord $
 */
public class JROdsExporterNature extends JROpenDocumentExporterNature
{

	public JROdsExporterNature(ExporterFilter filter)
	{
		super(filter);
	}

	/*
	 * (non-Javadoc)
	 * @see net.sf.jasperreports.engine.export.oasis.JROpenDocumentExporterNature#getOpenDocumentNature()
	 */
	protected byte getOpenDocumentNature() {

		return JROpenDocumentExporterNature.ODS_NATURE;
	}

	/**
	 * 
	 */
	public boolean isDeep()
	{
		return true;
	}
	
	/**
	 * 
	 */
	public boolean isSplitSharedRowSpan()
	{
		return false;
	}

}

==> jasperreports_3.7.4+dfsg.orig.tar.gz: jasperreports-3.7.4.orig/src/net/sf/jasperreports/engine/export/oasis/JROdsExporterNature.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * Contributors:
 * Greg Hilton
 */

package net.sf.jasperreports.engine.export.oasis;

import net.sf.jasperreports.engine.JRPrintFrame;
import net.sf.jasperreports.engine.export.ExporterFilter;

/**
 * @author sanda zaharia (shertage@users.sourceforge.net)
 * @version $Id: JROdsExporterNature.java 3875 2010-07-14 09:58:21Z teodord $
 */
public class JROdsExporterNature extends JROpenDocumentExporterNature
{

	public JROdsExporterNature(ExporterFilter filter)
	{
		super(filter);
	}

	/*
	 * (non-Javadoc)
	 * @see net.sf.jasperreports.engine.export.oasis.JROpenDocumentExporterNature#getOpenDocumentNature()
	 */
	protected byte getOpenDocumentNature() {

		return JROpenDocumentExporterNature.ODS_NATURE;
	}

	/**
	 * 
	 */
	public boolean isDeep(JRPrintFrame frame)
	{
		return true;
	}
	
	/**
	 * 
	 */
	public boolean isSplitSharedRowSpan()
	{
		return false;
	}

}
